@@ -382,18 +382,27 @@ Arnolfini.portletLinks = function ()
 	$('.portletStaticText ul li a').not("#FooterPortletManager .portletStaticText ul li a").each(function()
 		{
 			var elem = $(this);
-			var URL = $(this).attr("href") + '/get_number_of_results';
+			var link = $(this).attr("href") 
+			var URL = link + '/get_number_of_results';
+			
+			if (link == window.location.href)
+			{
+				$(this).addClass("highlighted")
+			}
 			
 			$.getJSON(URL, function(data)
 				  {
 					if (data != null)
 					{
 						var count = $('<span class="resultCount"> '+data+'</span>')
-						elem.after(count);
 						if (data == 0)
 						{
 							elem.hide();
 						}
+						else
+						{
+							elem.after(count);
+						}
 					}
 				  });
 		});
